Documentation
¶
Index ¶
Constants ¶
const NoBookToDownload = -1
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Progress ¶
type Progress interface {
// TakeRateLimit would wait until the rate limit is available.
TakeRateLimit()
// AcquireBookID would find the book id from the assign array.
AcquireBookID() int64
// SaveBookID would save the download progress.
SaveBookID(bookID int64) error
// Finished would tell the called whether all the books have downloaded.
Finished() bool
// Size would return the book size.
Size() int64
}
Click to show internal directories.
Click to hide internal directories.